/*
Calculator-komponentin luokkaosa 

Komponentin luokkaosassa on TypeScriptillä koodattu sovelluslogiikka
Luokasta välitetään dataa käyttöliittymään eli templaattiin ja toisinpäin.
Luokkaosaa kutsutaan myös varsinaiseksi komponentiksi, sillä se sisältää
kaikki komponentin osat määriteltynä dekoraattorissa.

Laskin käyttää signaalimuuttujia, joissa tapahtuvat muutokset välittyvät
välittömästi tulokseen. Laskin on siis reaktiivinen ja erittäin tehokkaalla tavalla
DOMin muutostenhallinnan näkökumasta.

Signaalimuuttujasta saadaan arvo ulos tekemällä siitä getterimetodi
eli laittamalla sen perään metodisulut.
*/

import { Component, computed, signal } from '@angular/core';
import { CommonModule } from '@angular/common';
import { FormsModule } from '@angular/forms';

// @Component -dekoraattorimetodin argumenttina
// olevassa oliossa määritellään komponentin osat
@Component({
  selector: 'app-calculator',
  standalone: true,
  imports: [CommonModule, FormsModule], // komponentin riippuvuudet
  templateUrl: './calculator.component.html',
  styleUrls: ['./calculator.component.css'],
})

export class CalculatorComponent {
  // Ominaisuudet
  
  // signaalimuuttujat on alustettu nolliksi jo esittelyssä
  val1 = signal<number>(0);
  val2 = signal<number>(0);
  // Operaattorin signaalimuuttuja on alustettu plussaksi
  op = signal<string>('+');
  // result lasketaan heti signaalimuuttujista
  result = computed(() => this.val1() + this.val2()); 

  // Metodit
  
  // Asettaa signaalimuuttujalle uuden arvon
  setVal1(val1: string) {
    this.val1.set(parseInt(val1));
  }

  setVal2(val2: string) {
    this.val2.set(parseInt(val2));
  }

  // Valitsee operaattorin laskutoimituksille ja tuottaa
  // signaalimuuttujista tuloksen
  setOp(op: string) {
    if (op === '+') {
      this.result = computed(() => this.val1() + this.val2());
      //console.log(this.result());
    } else if (op === '-') {
      this.result = computed(() => this.val1() - this.val2());
    }
    else if (op === '*') {
      this.result = computed(() => this.val1() * this.val2());
    }
  }
}
